#
# spec file for package python-CommonMark
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-CommonMark
Version:        0.7.5
Release:        lp151.3.1
Summary:        Python parser for the CommonMark Markdown spec
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://pypi.python.org/pypi/CommonMark
Source:         https://files.pythonhosted.org/packages/source/C/CommonMark/CommonMark-%{version}.tar.gz
BuildRequires:  %{python_module future}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-future
BuildArch:      noarch
%ifpython2
Obsoletes:      %{oldpython}-commonmark < %{version}
Provides:       %{oldpython}-commonmark = %{version}
%endif
%ifpython3
Provides:       python3-commonmark = %{version}
Obsoletes:      python3-commonmark < %{version}
%endif
%python_subpackages

%description
Pure Python port of jgm's stmd.js, a Markdown parser and renderer for the
CommonMark specification, using only native modules.

%package -n %{name}-doc
Summary:        Documentation for CommonMark
Group:          Documentation/HTML
Provides:       %{python_module CommonMark-doc = %{version}}

%description -n %{name}-doc
Documentation for Pure Python port of jgm's stmd.js, a Markdown parser and
renderer for the CommonMark specification, using only native modules.

%package -n cmark-python
Summary:        CommonMark parsing and rendering program in python
Group:          Development/Languages/Python
Requires:       python3-CommonMark = %{version}
Conflicts:      cmark

%description -n cmark-python
Pure Python port of jgm's stmd.js, a Markdown parser and renderer for the
CommonMark specification, using only native modules.

This package provides the "cmark" executable, to avoid conflicts with other
implementations.

%prep
%setup -q -n CommonMark-%{version}
chmod -x LICENSE
chmod -x README.rst
sed -i "s/\r//g" LICENSE
# find and remove unneeded shebangs
find CommonMark -name "*.py" | xargs sed -i '1 {/^#!/ d}'

%build
%python_build

%install
%python_install

%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Test broken due to encoding issue
# %check
# export LANG=en_US.UTF-8
# export PYTHONPATH=%{buildroot}%{python_sitelib}
# python setup.py test

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/CommonMark/
%{python_sitelib}/CommonMark-%{version}-py*.egg-info

%files -n %{name}-doc
%license LICENSE
%doc spec.txt

%files -n cmark-python
%license LICENSE
%doc spec.txt
%{_bindir}/cmark

%changelog
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sat Apr  7 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 0.7.5:
  * Fixed smart dashes bug in Python 3 (from @alvra)
* Mon Oct 30 2017 arun@gmx.de
- update to version 0.7.4:
  * The CommonMark spec has been updated to 0.28.
* Wed Jun 21 2017 dimstar@opensuse.org
- Fix typo in Requires (pyython3 -> python3).
* Fri Jun  9 2017 jengelh@inai.de
- A roadmap does not belong into the description.
- Resolve typographicly wrong apostrophe.
* Sat May  6 2017 toddrme2178@gmail.com
- Fix Provides/Obsoletes.
* Fri Apr 21 2017 toddrme2178@gmail.com
- Split "cmark" executable into own package to avoid conflicts with
  the cmark C reference implementation.
* Mon Apr  3 2017 toddrme2178@gmail.com
- Update to 0.7.3
  * The CommonMark spec has been updated to 0.27.
- Update to 0.7.2
  * Removed outdated files from distributed packages, reported by @hyperknot
- Update to 0.7.1
  * Updated CommonMark spec to 0.26.
  * Fixed JSON output invoked by `cmark -aj somefile.md`, reported by @rplCloud
  * Fixed a bug with `dumpAST()` on ordered lists, from @rflynn
- Update to 0.7.0
  * The `cmark.py` script is now just called `cmark`.
  * Fixed a bug where the `cmark.py` script contained a bogus path, reported
    by @yuhui-lin.
  * Fixed a bug where a TypeError could occur, reported by @civalin.
- Update to 0.6.4
  * The CommonMark spec has been updated to 0.25.
  * The HtmlRenderer has been refactored based on upstream changes in commonmark.js.
  * Python 2 fixes from @eric-wieser
  * Contributions from @funkybob and @hyperknot
- Update to 0.6.3
  * CommonMark-py now supports Python 2.6.
  * The CommonMark spec has been updated to 0.24.
- Update to 0.6.2
  * Fixed a UnicodeEncodeError when parsing unicode entities on
    Python 2. As a result, CommonMark-py now relies on the "future"
    module in Python 2, as documented in setup.py. This can be found on
    pypi: https://pypi.python.org/pypi/future
- Update to 0.6.1
  * Fixed an IndexError exception that occurred when input string
    was empty.
- Update to 0.6.0
  * CommonMark-py now complies to the 0.23 CommonMark spec
    http://spec.commonmark.org/0.23/
  * The ExtensionBlock has been removed in this release, since
    the parser has been rewritten.
  * Added a compatibility fix for Python 2.6, but this version
    of Python still isn't really supported.
  * `HTMLRenderer` has been renamed to `HtmlRenderer`.
  * `DocParser` has been renamed to `Parser`.
- Update to 0.5.5
  * Random bug fixes
  * Internal code structure changes
  * Compatibility fixes for Python 3
- Initial singlespec version
* Sun May  8 2016 arun@gmx.de
- specfile:
  * changed to https for source url
  * updated source url to files.pythonhosted.org
* Wed Dec  9 2015 bruno@ioda-net.ch
- Initial packaging on obs
